(use test)

(include "../isbn.scm")
(import isbn)

(test-group "ISBN-10"
	    (test "normal isbn" #t (valid-isbn? "3895760633"))
	    (test "isbn with X as check digit" #t (valid-isbn? "052103311X"))
	    (test "dashes as separators" #t (valid-isbn? "0-521-03311-X"))
	    (test "spaces as separators" #t (valid-isbn? "0 521 03311 X"))
	    (test "spaces and dashes (should fail but we are forgiving"
		  #t (valid-isbn? "0-521-03311 X"))
	    (test "uncommon separator places"
		  #t (valid-isbn? "0-5--2-1--03-3-1-1X"))
	    (test "wrong number" #f (valid-isbn? "1123122312")))

(test-group "ISBN-13"
	    (test "normal isbn-13" #t (valid-isbn? "9780387202488"))
	    (test "isbn with 0 check digit (10)"
		  #t (valid-isbn? "9783937514390")))

(test-group "ISBN classification"
	    (test "ISBN-10" 10 (isbn-type "3895760633"))
	    (test "ISBN-13" 13 (isbn-type "978-8-17525-766-5"))
	    (test "Invalid ISBN" #f (isbn-type "1123122312")))

(test-group "ISBN upgrade"
	    (test "normal isbn" "978-8-17525-766-5" (isbn10->isbn13 "817525766-0"))
	    (test "isbn with X as check digit" "978-0-52103-311-4" (isbn10->isbn13 "052103311X")))

(test-group "normalize-isbn"
	    (test "Normalize ISBN-13 (with 10 check digit)"
		  "9783937514390" (normalize-isbn "978-3-937514-39-0"))
	    (test "Normalize ISBN-10 (with 10 check digit)"
		  "052103311X" (normalize-isbn "0-521-03311-X")))
